# Tutorials

For a quick introduction to `AnnData`, check out {doc}`Getting Started with AnnData <notebooks/getting-started>`.

For working with the experimental data loaders also see {ref}`experimental-api`.

```{toctree}
:maxdepth: 1

notebooks/getting-started
notebooks/annloader
notebooks/anncollection
notebooks/anncollection-annloader
notebooks/anndata_dask_array
notebooks/awkward-arrays
notebooks/{read,write}_dispatched
notebooks/read_lazy
zarr-v3
```
